@@ -1,162 +1,21 @@
-import operator
 from copy import deepcopy
+from typing import Any, Sequence, Union
 
-from pandas.api.extensions import ExtensionArray, ExtensionDtype, ExtensionScalarOpsMixin
-from pandas.core.arrays.base import try_cast_to_ea
-from pandas.core import ops
-from pandas.compat import set_function_name
-from pandas.core.dtypes.generic import ABCExtensionArray, ABCIndexClass, ABCSeries
-from pandas.core.dtypes.common import is_array_like, is_list_like
-
-from typing import Sequence, Any, Union, List
-from pandas.core.dtypes.generic import ABCExtensionArray
-
-from pandas._typing import ArrayLike
 import numpy as np
 import pandas as pd
-
+from ladybug.datacollection import BaseCollection
+from pandas._typing import ArrayLike
+from pandas.api.extensions import (ExtensionArray, ExtensionDtype,
+                                   ExtensionScalarOpsMixin)
+from pandas.core.dtypes.generic import ABCExtensionArray
 from scipy import stats
 
-from pandas.core.arrays.numpy_ import PandasArray
-
-from ladybug.datacollection import BaseCollection, HourlyDiscontinuousCollection
-from ladybug.dt import DateTime
-
 from .dtype import LadybugDType
 
-
 COMPARISON_OPS = ['eq', 'ne', 'lt', 'gt', 'le', 'ge']
 
-class LadybugExtensionScalarOpsMixin(ExtensionScalarOpsMixin):
-    """
-    A mixin for defining  ops on an ExtensionArray.
 
-    It is assumed that the underlying scalar objects have the operators
-    already defined.
-
-    Notes
-    -----
-    If you have defined a subclass MyExtensionArray(ExtensionArray), then
-    use MyExtensionArray(ExtensionArray, ExtensionScalarOpsMixin) to
-    get the arithmetic operators.  After the definition of MyExtensionArray,
-    insert the lines
-
-    MyExtensionArray._add_arithmetic_ops()
-    MyExtensionArray._add_comparison_ops()
-
-    to link the operators to your class.
-
-    .. note::
-
-       You may want to set ``__array_priority__`` if you want your
-       implementation to be called when involved in binary operations
-       with NumPy arrays.
-    """
-
-    @classmethod
-    def _create_method(cls, op, coerce_to_dtype=True):
-        """
-        A class method that returns a method that will correspond to an
-        operator for an ExtensionArray subclass, by dispatching to the
-        relevant operator defined on the individual elements of the
-        ExtensionArray.
-
-        Parameters
-        ----------
-        op : function
-            An operator that takes arguments op(a, b)
-        coerce_to_dtype : bool, default True
-            boolean indicating whether to attempt to convert
-            the result to the underlying ExtensionArray dtype.
-            If it's not possible to create a new ExtensionArray with the
-            values, an ndarray is returned instead.
-
-        Returns
-        -------
-        Callable[[Any, Any], Union[ndarray, ExtensionArray]]
-            A method that can be bound to a class. When used, the method
-            receives the two arguments, one of which is the instance of
-            this class, and should return an ExtensionArray or an ndarray.
-
-            Returning an ndarray may be necessary when the result of the
-            `op` cannot be stored in the ExtensionArray. The dtype of the
-            ndarray uses NumPy's normal inference rules.
-
-        Examples
-        --------
-        Given an ExtensionArray subclass called MyExtensionArray, use
-
-        >>> __add__ = cls._create_method(operator.add)
-
-        in the class definition of MyExtensionArray to create the operator
-        for addition, that will be based on the operator implementation
-        of the underlying elements of the ExtensionArray
-        """
-
-        def _binop(self, other):
-            def convert_values(param):
-                if isinstance(param, ExtensionArray) or is_list_like(param):
-                    ovalues = param
-                else:  # Assume its an object
-                    ovalues = [param] * len(self)
-                return ovalues
-
-            if isinstance(other, (ABCSeries, ABCIndexClass)):
-                # rely on pandas to unbox and dispatch to us
-                return NotImplemented
-
-            if isinstance(other, LadybugArrayType):
-                if self.dtype == other.dtype:
-                    lvalues = self
-                    rvalues = other
-                else:
-
-                    lvalues = self.data
-                    rvalues = other.data
-
-                    # Special case for comparison operations
-                    # Values cannot be compared if they are
-                    # of a different LadybugDType
-                    if op.__name__ in COMPARISON_OPS:
-                        res = [False]* len(lvalues)
-                        return res
-
-            else:
-                lvalues = self.data
-                rvalues = convert_values(other)
-
-
-            # If the operator is not defined for the underlying objects,
-            # a TypeError should be raised
-            res = [op(a, b) for (a, b) in zip(lvalues, rvalues)]
-
-            def _maybe_convert(arr):
-                if coerce_to_dtype:
-                    # https://github.com/pandas-dev/pandas/issues/22850
-                    # We catch all regular exceptions here, and fall back
-                    # to an ndarray.
-                    if isinstance(rvalues, ExtensionArray) and rvalues.dtype != self.dtype:
-                        res = np.asarray(arr)
-                    else:
-                        res = try_cast_to_ea(self, arr)
-                    if not isinstance(res, type(self)):
-                        # exception raised in _from_sequence; ensure we have ndarray
-                        res = np.asarray(arr)
-                else:
-                    res = np.asarray(arr)
-                return res
-
-            if op.__name__ in {"divmod", "rdivmod"}:
-                a, b = zip(*res)
-                return _maybe_convert(a), _maybe_convert(b)
-
-            return _maybe_convert(res)
-
-        op_name = ops._get_op_name(op, True)
-        return set_function_name(_binop, op_name, cls)
-
-
-class LadybugArrayType(ExtensionArray, LadybugExtensionScalarOpsMixin):
+class LadybugArrayType(ExtensionArray, ExtensionScalarOpsMixin):
 
     _dtype = LadybugDType()
 
@@ -176,7 +35,8 @@ class LadybugArrayType(ExtensionArray, LadybugExtensionScalarOpsMixin):
             values = values.data
             self._dtype = values.dtype
         else:
-            values = np.asarray(values, dtype=dtype)
+            values = np.asarray(values)
+            self._dtype = values.dtype
 
         # TODO: dtype?
         if copy:
@@ -186,7 +46,6 @@ class LadybugArrayType(ExtensionArray, LadybugExtensionScalarOpsMixin):
             #     self._dtype = copy.deepcopy(self._dtype)
 
         self.data = values
-        
 
     @classmethod
     def _from_sequence(cls, scalars: Sequence, dtype=None, copy=False):
@@ -216,7 +75,6 @@ class LadybugArrayType(ExtensionArray, LadybugExtensionScalarOpsMixin):
 
         return cls(scalars, dtype=dtype, copy=copy)
 
-
     @classmethod
     def _from_sequence_of_strings(cls, strings, dtype=None, copy=False):
         """
@@ -263,7 +121,6 @@ class LadybugArrayType(ExtensionArray, LadybugExtensionScalarOpsMixin):
             raise f'Original value of type {type(original)} not supported'
 
         return cls(values, dtype)
-        
 
     @classmethod
     def _from_data_collection(cls, datacollection: BaseCollection):
@@ -275,21 +132,19 @@ class LadybugArrayType(ExtensionArray, LadybugExtensionScalarOpsMixin):
         Returns:
             LadybugArrayType -- A Ladybug Array
         """
-        dtype =  LadybugDType.construct_from_header(datacollection.header)
+        dtype = LadybugDType.construct_from_header(datacollection.header)
 
         return cls(values=datacollection.values, dtype=dtype)
 
-    
     # def to_hourly_discontinuous_collection(self, datetimes: List[DateTime]) -> HourlyDiscontinuousCollection:
     #     assert len(self.data) == len(datetimes), f'Datetime index of length {len(datetimes)} does not match length of array {len(self)}'
 
     #     return HourlyDiscontinuousCollection(
     #         header=self.dtype.to_header(),
     #         values=self.data.tolist(),
-    #         datetimes=datetimes,    
+    #         datetimes=datetimes,
     #     )
 
-
     def convert_to_unit(self, unit: str):
         """Convert the Data Collection to the input unit
 
@@ -303,16 +158,16 @@ class LadybugArrayType(ExtensionArray, LadybugExtensionScalarOpsMixin):
     def convert_to_ip(self):
         """Convert the Data Collection to IP units."""
         self.data, self.dtype.unit = self.dtype.data_type.to_ip(
-                self.data, self.dtype.unit)
+            self.data, self.dtype.unit)
 
     def convert_to_si(self):
         """Convert the Data Collection to SI units."""
         self.data, self.dtype.unit = self.dtype.data_type.to_si(
-                self.data, self.dtype.unit)
+            self.data, self.dtype.unit)
 
     def to_unit(self, unit):
         """Return a Data Collection in the input unit
-        
+
         Arguments:
             unit {str} -- A unit string that exists for the data type
 
@@ -335,7 +190,7 @@ class LadybugArrayType(ExtensionArray, LadybugExtensionScalarOpsMixin):
 
     def to_si(self):
         """Return a Data Collection in SI units
-        
+
         Returns:
             LadybugArrayType -- A Ladybug Array converted to the desired unit
         """
@@ -343,7 +198,6 @@ class LadybugArrayType(ExtensionArray, LadybugExtensionScalarOpsMixin):
         new_data_c.convert_to_si()
         return new_data_c
 
-
     def __getitem__(self, item):
         # type (Any) -> Any
         """
@@ -373,20 +227,28 @@ class LadybugArrayType(ExtensionArray, LadybugExtensionScalarOpsMixin):
         elif isinstance(item, slice):
             pass
         elif isinstance(item, np.ndarray):
-            pass
+            if item.dtype == bool and len(item) != len(self):
+                raise IndexError(
+                    f'Boolean index has wrong length: {item.size} instead of {self.data.size}')
         elif isinstance(item, list):
             try:
                 item = np.asarray(item, dtype=np.int_)
-            except Exception as e:        
-                raise ValueError("Cannot index with an integer indexer containing NA values")
+            except Exception as e:
+                raise ValueError(
+                    "Cannot index with an integer indexer containing NA values")
 
         elif isinstance(item, pd.core.arrays.boolean.BooleanArray):
-            item = item.to_numpy(dtype="bool", na_value=False) 
+            if len(item) != len(self):
+                raise IndexError(
+                    f'Boolean index has wrong length: {len(item)} instead of {len(self)}')
+
+            item = item.to_numpy(dtype="bool", na_value=False)
         elif isinstance(item, pd.core.arrays.integer.IntegerArray):
             try:
                 item = item.to_numpy(dtype="int", na_value=pd.NA)
             except Exception as e:
-                raise ValueError("Cannot index with an integer indexer containing NA values")
+                raise ValueError(
+                    "Cannot index with an integer indexer containing NA values")
         else:
             raise IndexError(f'Item type note recognised {type(item)}')
 
@@ -400,7 +262,6 @@ class LadybugArrayType(ExtensionArray, LadybugExtensionScalarOpsMixin):
         import pyarrow as pa
         return pa.array(self.data, type=pa.float64())
 
-
     def __len__(self) -> int:
         """
         Length of this array
@@ -410,28 +271,27 @@ class LadybugArrayType(ExtensionArray, LadybugExtensionScalarOpsMixin):
         """
         return self.data.size
 
-
     def __setitem__(self, key: Union[int, np.ndarray], value: Any) -> None:
         """
         Set one or more values inplace.
-    
+
         This method is not required to satisfy the pandas extension array
         interface.
-    
+
         Parameters
         ----------
         key : int, ndarray, or slice
             When called from, e.g. ``Series.__setitem__``, ``key`` will be
             one of
-    
+
             * scalar int
             * ndarray of integers.
             * boolean ndarray
             * slice object
-    
+
         value : ExtensionDtype.type, Sequence[ExtensionDtype.type], or object
             value or values to be set of ``key``.
-    
+
         Returns
         -------
         None
@@ -455,7 +315,6 @@ class LadybugArrayType(ExtensionArray, LadybugExtensionScalarOpsMixin):
         # Note, also, that Series/DataFrame.where internally use __setitem__
         # on a copy of the data.
 
-
         if isinstance(key, pd.core.arrays.BooleanArray):
             key = key.fillna(False)
             key = key.to_numpy(dtype="bool")
@@ -464,7 +323,8 @@ class LadybugArrayType(ExtensionArray, LadybugExtensionScalarOpsMixin):
                 key = key.to_numpy(dtype="int")
             except ValueError as error:
                 if 'Specify an appropriate \'na_value\'' in str(error):
-                    raise ValueError('Cannot index with an integer indexer containing NA values')
+                    raise ValueError(
+                        'Cannot index with an integer indexer containing NA values')
                 raise error
 
         elif isinstance(key, list):
@@ -481,13 +341,15 @@ class LadybugArrayType(ExtensionArray, LadybugExtensionScalarOpsMixin):
                 else:
                     list_item += 1
 
-            assert list_type is not None, IndexError('arrays used as indices must be of integer (or boolean) type')
+            assert list_type is not None, IndexError(
+                'arrays used as indices must be of integer (or boolean) type')
 
             try:
                 key = np.asarray(key, dtype=list_type)
             except TypeError as error:
                 if 'int() argument must be a string, a bytes-like object or a number, not \'NAType\'' in str(error):
-                    raise ValueError('Cannot index with an integer indexer containing NA values')
+                    raise ValueError(
+                        'Cannot index with an integer indexer containing NA values')
 
                 raise error
 
@@ -502,9 +364,8 @@ class LadybugArrayType(ExtensionArray, LadybugExtensionScalarOpsMixin):
             else:
                 raise error
 
-    
     # def __add__(self, other):
-        
+
     #     if isinstance(other, self.__class__):
     #         self.data += other.data
 
@@ -524,7 +385,6 @@ class LadybugArrayType(ExtensionArray, LadybugExtensionScalarOpsMixin):
         # else:
         #     return self._dtype
 
-
     @property
     def nbytes(self) -> int:
         """
@@ -535,7 +395,6 @@ class LadybugArrayType(ExtensionArray, LadybugExtensionScalarOpsMixin):
         # return self._itemsize * self.__len__
         return self.data.nbytes
 
-
     @property
     def _ndarray(self):
         return self.data
@@ -561,7 +420,7 @@ class LadybugArrayType(ExtensionArray, LadybugExtensionScalarOpsMixin):
         ------
         TypeError : subclass does not define reductions
         """
-        
+
         root = np
 
         child_kwargs = {}
@@ -585,7 +444,6 @@ class LadybugArrayType(ExtensionArray, LadybugExtensionScalarOpsMixin):
             # return getattr(self.data, name)(**child_kwargs)
             return getattr(root, name)(self.data, **child_kwargs)
 
-
     def isna(self) -> ArrayLike:
         """
         A 1-D array indicating if each value is missing.
@@ -605,8 +463,7 @@ class LadybugArrayType(ExtensionArray, LadybugExtensionScalarOpsMixin):
         """
         return np.isnan(self.data)
 
-
-    def value_counts(self, dropna=False):
+    def value_counts(self, dropna=True):
         """
         Return a Series containing counts of unique values.
 
@@ -619,7 +476,7 @@ class LadybugArrayType(ExtensionArray, LadybugExtensionScalarOpsMixin):
         -------
         Series
         """
-        from pandas import Series, Index
+        from pandas import Index, Series
 
         if dropna:
             values = self[~self.isna()].data
@@ -630,7 +487,6 @@ class LadybugArrayType(ExtensionArray, LadybugExtensionScalarOpsMixin):
 
         return Series(counts, index=unique, dtype="int64")
 
-
     def take(
         self, indices: Sequence[int], allow_fill: bool = False, fill_value: Any = None
     ) -> "ExtensionArray":
@@ -705,10 +561,10 @@ class LadybugArrayType(ExtensionArray, LadybugExtensionScalarOpsMixin):
         # the user-facing type to the storage type, before using
         # pandas.api.extensions.take
         copy = self.copy()
-        copy.data = pd.api.extensions.take(copy.data, indices, allow_fill=allow_fill, fill_value=fill_value)
-        
-        return copy
+        copy.data = pd.api.extensions.take(
+            copy.data, indices, allow_fill=allow_fill, fill_value=fill_value)
 
+        return copy
 
     def copy(self) -> "ExtensionArray":
         """
@@ -724,7 +580,6 @@ class LadybugArrayType(ExtensionArray, LadybugExtensionScalarOpsMixin):
             copy=True,
         )
 
-
     def view(self, dtype=None) -> Union[ABCExtensionArray, np.ndarray]:
         """
         Return a view on the array.
@@ -748,8 +603,6 @@ class LadybugArrayType(ExtensionArray, LadybugExtensionScalarOpsMixin):
 
         return self.__class__._from_factorized(self.data, self)
 
-
-
     @classmethod
     def _concat_same_type(
         cls, to_concat: Sequence["ExtensionArray"]
@@ -766,7 +619,6 @@ class LadybugArrayType(ExtensionArray, LadybugExtensionScalarOpsMixin):
         data = np.concatenate([ga.data for ga in to_concat])
         return cls._from_factorized(data, to_concat)
 
-
     def astype(self, dtype, copy=True):
         if isinstance(dtype, self.dtype.__class__):
             if copy:
